@@ -54,60 +54,6 @@ static S2N_RESULT s2n_test_security_policies_compatible(const struct s2n_securit
     return S2N_RESULT_OK;
 }
 
-static S2N_RESULT s2n_test_get_missing_duplicate_signature_scheme(
-        const struct s2n_signature_scheme *const *policy_schemes, size_t policy_schemes_count,
-        uint8_t minimum_policy_version, uint8_t maximum_policy_version,
-        const struct s2n_signature_scheme **duplicate)
-{
-    if (policy_schemes_count > 0) {
-        RESULT_ENSURE_REF(policy_schemes);
-    }
-    RESULT_ENSURE_REF(duplicate);
-    *duplicate = NULL;
-
-    const struct s2n_signature_preferences *all_schemes = security_policy_test_all.signature_preferences;
-
-    /* Check all schemes in target policy */
-    for (int i = 0; i < policy_schemes_count; i++) {
-        const struct s2n_signature_scheme *from_policy = policy_schemes[i];
-        EXPECT_NOT_NULL(from_policy);
-
-        /* Check if duplicates exist for the scheme */
-        for (size_t j = 0; j < all_schemes->count; j++) {
-            const struct s2n_signature_scheme *from_all = all_schemes->signature_schemes[j];
-            EXPECT_NOT_NULL(from_all);
-
-            /* Skip if not a duplicate */
-            if (from_all == from_policy) {
-                continue;
-            } else if (from_all->iana_value != from_policy->iana_value) {
-                continue;
-            } else if (from_all->maximum_protocol_version
-                    && from_all->maximum_protocol_version < minimum_policy_version) {
-                continue;
-            } else if (from_all->minimum_protocol_version
-                    && from_all->minimum_protocol_version > maximum_policy_version) {
-                continue;
-            }
-            *duplicate = from_all;
-
-            /* Check whether duplicate is also in the target policy */
-            for (size_t k = 0; k < policy_schemes_count; k++) {
-                const struct s2n_signature_scheme *possible_match = policy_schemes[k];
-                EXPECT_NOT_NULL(possible_match);
-                if (*duplicate == possible_match) {
-                    *duplicate = NULL;
-                    break;
-                }
-            }
-            if (*duplicate) {
-                return S2N_RESULT_OK;
-            }
-        }
-    }
-    return S2N_RESULT_OK;
-}
-
 int main(int argc, char **argv)
 {
     BEGIN_TEST();
@@ -659,7 +605,7 @@ int main(int argc, char **argv)
         EXPECT_EQUAL(config->security_policy->ecc_preferences, &s2n_ecc_preferences_20140601);
 
         EXPECT_SUCCESS(s2n_config_set_cipher_preferences(config, "default_tls13"));
-        EXPECT_EQUAL(config->security_policy, &security_policy_default_tls13);
+        EXPECT_EQUAL(config->security_policy, &security_policy_20240417);
         EXPECT_EQUAL(config->security_policy->cipher_preferences, &cipher_preferences_20210831);
         EXPECT_EQUAL(config->security_policy->kem_preferences, &kem_preferences_null);
         EXPECT_EQUAL(config->security_policy->signature_preferences, &s2n_signature_preferences_20200207);
@@ -785,7 +731,7 @@ int main(int argc, char **argv)
 
         EXPECT_SUCCESS(s2n_connection_set_cipher_preferences(conn, "default_tls13"));
         EXPECT_SUCCESS(s2n_connection_get_security_policy(conn, &security_policy));
-        EXPECT_EQUAL(security_policy, &security_policy_default_tls13);
+        EXPECT_EQUAL(security_policy, &security_policy_20240417);
         EXPECT_EQUAL(security_policy->cipher_preferences, &cipher_preferences_20210831);
         EXPECT_EQUAL(security_policy->kem_preferences, &kem_preferences_null);
         EXPECT_EQUAL(security_policy->signature_preferences, &s2n_signature_preferences_20200207);
@@ -875,7 +821,6 @@ int main(int argc, char **argv)
 
                 /* If scheme will be used for pre-tls1.3 */
                 if (min_version < S2N_TLS13) {
-                    EXPECT_NULL(scheme->signature_curve);
                     EXPECT_NOT_EQUAL(scheme->sig_alg, S2N_SIGNATURE_RSA_PSS_PSS);
                 }
             }
@@ -1075,52 +1020,5 @@ int main(int argc, char **argv)
         };
     };
 
-    /* Policies must include all signature schemes that share an IANA value */
-    {
-        for (int i = 0; security_policy_selection[i].version != NULL; i++) {
-            security_policy = security_policy_selection[i].security_policy;
-            EXPECT_NOT_NULL(security_policy);
-            const uint8_t max_protocol_version = security_policy_selection[i].supports_tls13 ?
-                    s2n_highest_protocol_version :
-                    S2N_TLS12;
-
-            /* Check signature scheme preferences */
-            {
-                const struct s2n_signature_scheme *duplicate = NULL;
-                EXPECT_OK(s2n_test_get_missing_duplicate_signature_scheme(
-                        security_policy->signature_preferences->signature_schemes,
-                        security_policy->signature_preferences->count,
-                        security_policy->minimum_protocol_version,
-                        max_protocol_version,
-                        &duplicate));
-
-                if (duplicate) {
-                    fprintf(stderr, "Policy: %s Scheme: %04x\n",
-                            security_policy_selection[i].version,
-                            duplicate->iana_value);
-                    FAIL_MSG("Missing signature scheme");
-                }
-            }
-
-            /* Check certificate signature scheme preferences */
-            if (security_policy->certificate_signature_preferences) {
-                const struct s2n_signature_scheme *duplicate = NULL;
-                EXPECT_OK(s2n_test_get_missing_duplicate_signature_scheme(
-                        security_policy->certificate_signature_preferences->signature_schemes,
-                        security_policy->certificate_signature_preferences->count,
-                        security_policy->minimum_protocol_version,
-                        max_protocol_version,
-                        &duplicate));
-
-                if (duplicate) {
-                    fprintf(stderr, "Policy: %s Scheme: %04x\n",
-                            security_policy_selection[i].version,
-                            duplicate->iana_value);
-                    FAIL_MSG("Missing certificate signature scheme");
-                }
-            }
-        }
-    }
-
     END_TEST();
 }
