@@ -124,6 +124,7 @@ static int s2n_config_cleanup(struct s2n_config *config)
     POSIX_GUARD(s2n_config_free_cert_chain_and_key(config));
     POSIX_GUARD(s2n_config_free_dhparams(config));
     POSIX_GUARD(s2n_free(&config->application_protocols));
+    POSIX_GUARD(s2n_free(&config->cert_authorities));
     POSIX_GUARD_RESULT(s2n_map_free(config->domain_name_to_cert_map));
 
     POSIX_CHECKED_MEMSET(config, 0, sizeof(struct s2n_config));
@@ -1224,7 +1225,7 @@ int s2n_config_get_supported_groups(struct s2n_config *config, uint16_t *groups,
     return S2N_SUCCESS;
 }
 
-int s2n_config_set_serialized_connection_version(struct s2n_config *config, s2n_serialization_version version)
+int s2n_config_set_serialization_version(struct s2n_config *config, s2n_serialization_version version)
 {
     POSIX_ENSURE_REF(config);
 
